module.exports = function(grunt) {

	grunt.initConfig({

		// Import package manifest
		pkg: grunt.file.readJSON("package.json"),

		// Banner definitions
		meta: {
			banner: "/*\n" +
				" *  <%= pkg.title || pkg.name %> - v<%= pkg.version %>\n" +
				" *  <%= pkg.description %>\n" +
				" *  <%= pkg.homepage %>\n" +
				" *\n" +
				" *  Made by <%= pkg.author.name %>\n" +
				" *  Under <%= pkg.license %> License\n" +
				" */\n"
		},

		// Concat definitions
		concat: {
			options: {
				banner: "<%= meta.banner %>"
			},
			dist: {
				src: ["src/jquery.numble.js"],
				dest: "dist/jquery.numble.js"
			}
		},

		// Lint definitions
		jshint: {
			files: ["src/jquery.numble.js"],
			options: {
				jshintrc: ".jshintrc"
			}
		},

		// Minify definitions
		uglify: {
			my_target: {
				files: {
        	"dist/jquery.numble.min.js": ["src/jquery.numble.js"],
					"demo/javascripts/jquery.numble.min.js": ["src/jquery.numble.js"]
      	}
			},
			options: {
				banner: "<%= meta.banner %>"
			}
		},

		// CoffeeScript compilation
		coffee: {
			compile: {
				files: {
					"dist/jquery.numble.js": "src/jquery.numble.coffee"
				}
			}
		},

		jasmine: {
	    test: {
	      src: 'src/**/*.js'
			},
	      options: {
	        specs: 'test/spec/test.js',
	        keepRunner : false,
					vendor: [
        		'bower_components/jquery/dist/jquery.js',
        		'bower_components/jasmine-jquery/lib/jasmine-jquery.js'
      		],
					outfile: 'test/_SpecRunner.html'
	      }
    },

		// watch for changes to source
		// Better than calling grunt a million times
		// (call 'grunt watch')
		watch: {
		    files: ['src/*'],
		    tasks: ['default']
		}

	});

	grunt.loadNpmTasks("grunt-contrib-concat");
	grunt.loadNpmTasks('grunt-contrib-jasmine');
	grunt.loadNpmTasks("grunt-contrib-jshint");
	grunt.loadNpmTasks("grunt-contrib-uglify");
	grunt.loadNpmTasks("grunt-contrib-coffee");
	grunt.loadNpmTasks("grunt-contrib-watch");

	grunt.registerTask("build", ["concat", "uglify"]);
	grunt.registerTask("default", ["jshint", "jasmine", "build"]);
	grunt.registerTask("travis", ["default"]);

};
